@@ -92,7 +92,10 @@ current_clocksource'
             kernel
 
         bugzilla_id:
-            1849082
+            1849082,1906301
+
+        customer_case_id:
+            02925130
 
         polarion_id:
             n/a
@@ -189,11 +192,8 @@ current_clocksource'
         cmd = "sudo rpm -qa|grep rhui"
         utils_lib.run_cmd(self, cmd, cancel_ret='0', msg='skip test if rhui is not installed')
 
-        check_cmd = "sudo cat /etc/redhat-release"
-        output = utils_lib.run_cmd(self,check_cmd, expect_ret=0, msg='check release name')
-        product_id = re.findall('\d.\d', output)[0]
-        self.log.info("Get product id: {}".format(product_id))
-        if product_id < '8.4':
+        product_id = utils_lib.get_product_id(self)
+        if float(product_id) < 8.4:
             self.skipTest('skip in earlier than el8.4')
         self.log.info("Auto registeration only supports aws platform for now.")
 
@@ -215,13 +215,19 @@ current_clocksource'
             utils_lib.run_cmd(self, cmd, msg='try to check rhsm.log')
             cmd = "sudo subscription-manager identity"
             out = utils_lib.run_cmd(self, cmd, msg='try to check subscription identity')
+            cmd = "sudo subscription-manager list --installed"
+            out = utils_lib.run_cmd(self, cmd, msg='try to list currently installed on the system')
             cmd = "sudo subscription-manager status"
             out = utils_lib.run_cmd(self, cmd, msg='try to check subscription status')
-            if 'Red Hat Enterprise Linux' in out:
+            if 'Red Hat Enterprise Linux' in out or 'Simple Content Access' in out:
                 self.log.info("auto subscription registered completed")
+                cmd = "sudo insights-client --register"
+                utils_lib.run_cmd(self, cmd, msg='check if insights-client can register successfully')
                 break
             end_time = time.time()
             if end_time - start_time > timeout:
+                cmd = "sudo insights-client --register"
+                utils_lib.run_cmd(self, cmd, msg='check if insights-client can register successfully')
                 self.fail("timeout({}s) to wait auto subscription registered completed".format(timeout))
             self.log.info('wait {}s and try to check again, timeout {}s'.format(interval, timeout))
             time.sleep(interval)
@@ -258,6 +264,7 @@ current_clocksource'
         utils_lib.run_cmd(self, cmd)
         cmd = "podman kill myctr1"
         utils_lib.run_cmd(self, cmd, expect_ret=0)
+        time.sleep(1)
         cmd = "podman inspect myctr1"
         utils_lib.run_cmd(self, cmd, expect_ret=0)
         cmd = "podman rm myctr1"
